==> domoticz-2020.2.tar.gz: domoticz-2020.2/dzVents/runtime/constants.lua <==
return {
	['ALERTLEVEL_GREEN'] = 1,
	['ALERTLEVEL_GREY'] = 0,
	['ALERTLEVEL_ORANGE'] = 3,
	['ALERTLEVEL_RED'] = 4,
	['ALERTLEVEL_YELLOW'] = 2,
	['BARO_CLOUDY'] = 'cloudy',	   -- true mapping to numbers is done in the device adapters for baro and temphumbaro devices
	['BARO_NOINFO'] = 'noinfo',
	['BARO_PARTLYCLOUDY'] = 'partlycloudy',
	['BARO_RAIN'] = 'rain',
	['BARO_STABLE'] = 'stable',
	['BARO_SUNNY'] = 'sunny',
	['BARO_THUNDERSTORM'] = 'thunderstorm',
	['BARO_UNSTABLE'] = 'unstable',
	['BASETYPE_CUSTOM_EVENT'] = 'custom',
	['BASETYPE_DEVICE'] = 'device',
	['BASETYPE_GROUP'] = 'group',
	['BASETYPE_HTTP_RESPONSE'] = 'httpResponse',
	['BASETYPE_SCENE'] = 'scene',
	['BASETYPE_SECURITY'] = 'security',
	['BASETYPE_SYSTEM_EVENT'] = 'system',
	['BASETYPE_TIMER'] = 'timer',
	['BASETYPE_VARIABLE'] = 'variable',
	['DATE'] = 'date',
	['EVENT_TYPE_CUSTOM'] = 'custom',
	['EVENT_TYPE_DEVICE'] = 'device',
	['EVENT_TYPE_GROUP'] = 'group',
	['EVENT_TYPE_HTTPRESPONSE'] = 'httpResponse',
	['EVENT_TYPE_SCENE'] = 'scene',
	['EVENT_TYPE_SECURITY'] = 'security',
	['EVENT_TYPE_SYSTEM'] = 'system',
	['EVENT_TYPE_TIMER'] = 'timer',
	['EVENT_TYPE_VARIABLE'] = 'variable',
	['EVOHOME_MODE_AUTO'] = 'Auto',
	['EVOHOME_MODE_AUTOWITHECO'] = 'AutoWithEco',
	['EVOHOME_MODE_AUTOWITHRESET'] = 'AutoWithReset',
	['EVOHOME_MODE_AWAY'] = 'Away',
	['EVOHOME_MODE_CUSTOM'] = 'Custom',
	['EVOHOME_MODE_DAYOFF'] = 'DayOff',
	['EVOHOME_MODE_FOLLOW_SCHEDULE'] = 'FollowSchedule',
	['EVOHOME_MODE_HEATINGOFF'] = 'HeatingOff',
	['EVOHOME_MODE_PERMANENT_OVERRIDE'] = 'PermanentOverride',
	['EVOHOME_MODE_TEMPORARY_OVERRIDE'] = 'TemporaryOverride',
	['FLOAT'] = 'float',
	['HUM_COMFORTABLE'] = 1,
	['HUM_DRY'] = 2,
	['HUM_NORMAL'] = 0,
	['HUM_WET'] = 3,
	['INTEGER'] = 'integer',
	['NSS_FIREBASE'] = 'fcm',
	['NSS_FIREBASE_CLOUD_MESSAGING'] = 'fcm',
	['NSS_GOOGLE_CLOUD_MESSAGING'] = 'gcm',  -- Only for backward compatibility. Will be deprecated soon
	['NSS_HTTP'] = 'http',
	['NSS_KODI'] = 'kodi',
	['NSS_LOGITECH_MEDIASERVER'] = 'lms',
	['NSS_NMA'] = 'nma',
	['NSS_PROWL'] = 'prowl',
	['NSS_PUSHALOT'] = 'pushalot',
	['NSS_PUSHBULLET'] = 'pushbullet',
	['NSS_PUSHOVER'] = 'pushover',
	['NSS_PUSHSAFER'] = 'pushsafer',
	['NSS_TELEGRAM'] = 'telegram',
	['PRIORITY_EMERGENCY'] = 2,
	['PRIORITY_HIGH'] = 1,
	['PRIORITY_LOW'] = -2,
	['PRIORITY_MODERATE'] = -1,
	['PRIORITY_NORMAL'] = 0,
	['SECURITY_ARMEDAWAY'] = 'Armed Away',
	['SECURITY_ARMEDHOME'] = 'Armed Home',
	['SECURITY_DISARMED'] = 'Disarmed',
	['SOUND_ALIEN'] = 'alien',
	['SOUND_BIKE'] = 'bike',
	['SOUND_BUGLE'] = 'bugle',
	['SOUND_CASH_REGISTER'] = 'cashregister',
	['SOUND_CLASSICAL'] = 'classical',
	['SOUND_CLIMB'] = 'climb',
	['SOUND_COSMIC'] = 'cosmic',
	['SOUND_DEFAULT'] = 'pushover',
	['SOUND_ECHO'] = 'echo',
	['SOUND_FALLING'] = 'falling',
	['SOUND_GAMELAN'] = 'gamelan',
	['SOUND_INCOMING'] = 'incoming',
	['SOUND_INTERMISSION'] = 'intermission',
	['SOUND_MAGIC'] = 'magic',
	['SOUND_MECHANICAL'] = 'mechanical',
	['SOUND_NONE'] = 'none',
	['SOUND_PERSISTENT'] = 'persistent',
	['SOUND_PIANOBAR'] = 'pianobar',
	['SOUND_SIREN'] = 'siren',
	['SOUND_SPACEALARM'] = 'spacealarm',
	['SOUND_TUGBOAT'] = 'tugboat',
	['SOUND_UPDOWN'] = 'updown',
	['STRING'] = 'string',
	['TIME'] = 'time',
}

==> domoticz-2021.1.tar.gz: domoticz-2021.1/dzVents/runtime/constants.lua <==
return {
	['ALERTLEVEL_GREEN'] = 1,
	['ALERTLEVEL_GREY'] = 0,
	['ALERTLEVEL_ORANGE'] = 3,
	['ALERTLEVEL_RED'] = 4,
	['ALERTLEVEL_YELLOW'] = 2,
	['BARO_CLOUDY'] = 'cloudy',	   -- true mapping to numbers is done in the device adapters for baro and temphumbaro devices
	['BARO_COMPUTE'] = 'compute',
	['BARO_NOINFO'] = 'noinfo',
	['BARO_PARTLYCLOUDY'] = 'partlycloudy',
	['BARO_RAIN'] = 'rain',
	['BARO_STABLE'] = 'stable',
	['BARO_SUNNY'] = 'sunny',
	['BARO_THUNDERSTORM'] = 'thunderstorm',
	['BARO_UNSTABLE'] = 'unstable',
	['BASETYPE_CUSTOM_EVENT'] = 'custom',
	['BASETYPE_DEVICE'] = 'device',
	['BASETYPE_GROUP'] = 'group',
	['BASETYPE_HTTP_RESPONSE'] = 'httpResponse',
	['BASETYPE_SHELLCOMMAND_RESPONSE'] = 'shellcommandResponse',
	['BASETYPE_SCENE'] = 'scene',
	['BASETYPE_SECURITY'] = 'security',
	['BASETYPE_SYSTEM_EVENT'] = 'system',
	['BASETYPE_TIMER'] = 'timer',
	['BASETYPE_VARIABLE'] = 'variable',
	['DATE'] = 'date',
	['EVENT_TYPE_CUSTOM'] = 'custom',
	['EVENT_TYPE_DEVICE'] = 'device',
	['EVENT_TYPE_GROUP'] = 'group',
	['EVENT_TYPE_HTTPRESPONSE'] = 'httpResponse',
	['EVENT_TYPE_SHELLCOMMANDRESPONSE'] = 'shellcommandResponse',
	['EVENT_TYPE_SCENE'] = 'scene',
	['EVENT_TYPE_SECURITY'] = 'security',
	['EVENT_TYPE_SYSTEM'] = 'system',
	['EVENT_TYPE_TIMER'] = 'timer',
	['EVENT_TYPE_VARIABLE'] = 'variable',
	['EVOHOME_MODE_AUTO'] = 'Auto',
	['EVOHOME_MODE_AUTOWITHECO'] = 'AutoWithEco',
	['EVOHOME_MODE_AUTOWITHRESET'] = 'AutoWithReset',
	['EVOHOME_MODE_AWAY'] = 'Away',
	['EVOHOME_MODE_CUSTOM'] = 'Custom',
	['EVOHOME_MODE_DAYOFF'] = 'DayOff',
	['EVOHOME_MODE_DAYOFFWITHECO'] = 'DayOffWithEco',
 	['EVOHOME_MODE_FOLLOW_SCHEDULE'] = 'FollowSchedule',
	['EVOHOME_MODE_HEATINGOFF'] = 'HeatingOff',
	['EVOHOME_MODE_PERMANENT_OVERRIDE'] = 'PermanentOverride',
	['EVOHOME_MODE_TEMPORARY_OVERRIDE'] = 'TemporaryOverride',
	['FLOAT'] = 'float',
	['HUM_COMFORTABLE'] = 1,
	['HUM_COMPUTE'] = -1,
	['HUM_DRY'] = 2,
	['HUM_NORMAL'] = 0,
	['HUM_WET'] = 3,
	['INTEGER'] = 'integer',
	['NSS_CLICKATELL'] = 'clickatell',
	['NSS_FIREBASE'] = 'fcm',
	['NSS_FIREBASE_CLOUD_MESSAGING'] = 'fcm',
	['NSS_GOOGLE_CLOUD_MESSAGING'] = 'gcm',  -- Only for backward compatibility. Will be deprecated soon
	['NSS_GOOGLE_DEVICES'] = 'Google_Devices',
	['NSS_HTTP'] = 'http',
	['NSS_KODI'] = 'kodi',
	['NSS_LOGITECH_MEDIASERVER'] = 'lms',
	['NSS_NMA'] = 'nma',
	['NSS_PROWL'] = 'prowl',
	['NSS_PUSHALOT'] = 'pushalot',
	['NSS_PUSHBULLET'] = 'pushbullet',
	['NSS_PUSHOVER'] = 'pushover',
	['NSS_PUSHSAFER'] = 'pushsafer',
	['NSS_TELEGRAM'] = 'telegram',
	['PRIORITY_EMERGENCY'] = 2,
	['PRIORITY_HIGH'] = 1,
	['PRIORITY_LOW'] = -2,
	['PRIORITY_MODERATE'] = -1,
	['PRIORITY_NORMAL'] = 0,
	['SECURITY_ARMEDAWAY'] = 'Armed Away',
	['SECURITY_ARMEDHOME'] = 'Armed Home',
	['SECURITY_DISARMED'] = 'Disarmed',
	['SOUND_ALIEN'] = 'alien',
	['SOUND_BIKE'] = 'bike',
	['SOUND_BUGLE'] = 'bugle',
	['SOUND_CASH_REGISTER'] = 'cashregister',
	['SOUND_CLASSICAL'] = 'classical',
	['SOUND_CLIMB'] = 'climb',
	['SOUND_COSMIC'] = 'cosmic',
	['SOUND_DEFAULT'] = 'pushover',
	['SOUND_ECHO'] = 'echo',
	['SOUND_FALLING'] = 'falling',
	['SOUND_GAMELAN'] = 'gamelan',
	['SOUND_INCOMING'] = 'incoming',
	['SOUND_INTERMISSION'] = 'intermission',
	['SOUND_MAGIC'] = 'magic',
	['SOUND_MECHANICAL'] = 'mechanical',
	['SOUND_NONE'] = 'none',
	['SOUND_PERSISTENT'] = 'persistent',
	['SOUND_PIANOBAR'] = 'pianobar',
	['SOUND_SIREN'] = 'siren',
	['SOUND_SPACEALARM'] = 'spacealarm',
	['SOUND_TUGBOAT'] = 'tugboat',
	['SOUND_UPDOWN'] = 'updown',
	['STATE_HEATING'] = 'Heating',
	['STATE_COOLING'] = 'Cooling',
	['STATE_IDLE'] = 'Idle',
	['STRING'] = 'string',
	['TIME'] = 'time',
}
